@@ -15,7 +15,7 @@ use constant FFR     => 'File::Find::Rule';
 
 use vars qw{$VERSION};
 BEGIN {
-        $VERSION = '0.20';
+        $VERSION = '0.21';
 }
 
 # Does exec work on this platform
@@ -229,11 +229,11 @@ sub main {
         }
 
 	# On some platforms (mostly Windows), we get errors because
-	# of Term::Cap issues. To avoid this, set TERM=dump if the
+	# of Term::Cap issues. To avoid this, set TERM=dumb if the
 	# user does not have a TERM value already.
 	# This doesn't remove all possible errors, just the most
 	# annoying and common ones.
-	$ENV{TERM} ||= 'dump';
+	$ENV{TERM} ||= 'dumb';
 
         # Hand off to the perl debugger
         unless ( pler->is_verbose ) {
